# encoding: utf-8
from setuptools import setup, find_packages

VERSION = '0.1.0'

setup(
    name='lybp',
    version=VERSION,
    description='a simple test',
    license='MIT',
    author='pypi060104',
    author_email='uijsj1102@163.com',
    packages=['lybp'],
    install_requires=[],
)